kerrgeodesic_gw: Gravitational radiation from material orbiting a Kerr black hole
=================================================================================

Description
-----------

Gravitational radiation from material orbiting a Kerr black hole

License
-------

GPLv2+

Upstream Contact
----------------

https://pypi.org/project/kerrgeodesic-gw/

